@@ -18,6 +18,10 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
+if (!$user->canViewView('console')) {
+  $view = 'error';
+  return;
+}
 $canEditMonitors = canEdit('Monitors');
 $canCreateMonitors = canCreate('Monitors');
 
@@ -108,8 +112,6 @@ $colAllAvailableMonitors = $resultMonitorFilters['selected_monitor_ids'];
 $displayMonitorIds = array_map(function($m){return $m['Id'];}, $displayMonitors);
 
 $show_storage_areas = (count($storage_areas) > 1) and (canEdit('System') ? 1 : 0);
-$maxWidth = 0;
-$maxHeight = 0;
 $zoneCount = 0;
 $total_capturing_bandwidth = 0;
 $total_fps = 0;
@@ -127,13 +129,6 @@ for ( $i = 0; $i < count($displayMonitors); $i++ ) {
   if ( !isset($status_counts[$monitor['Status']]) )
     $status_counts[$monitor['Status']] = 0;
   $status_counts[$monitor['Status']] += 1;
-
-  if ( $monitor['Capturing'] != 'None' ) {
-    $scaleWidth = reScale($monitor['Width'], $monitor['DefaultScale'], ZM_WEB_DEFAULT_SCALE);
-    $scaleHeight = reScale($monitor['Height'], $monitor['DefaultScale'], ZM_WEB_DEFAULT_SCALE);
-    if ( $maxWidth < $scaleWidth ) $maxWidth = $scaleWidth;
-    if ( $maxHeight < $scaleHeight ) $maxHeight = $scaleHeight;
-  }
   $zoneCount += $monitor['ZoneCount'];
 
   $counts = array();
@@ -151,8 +146,6 @@ for ( $i = 0; $i < count($displayMonitors); $i++ ) {
   }
   unset($monitor);
 } // end foreach display monitor
-$cycleWidth = $maxWidth;
-$cycleHeight = $maxHeight;
 
 noCacheHeaders();
 
@@ -335,7 +328,6 @@ for ($monitor_i = 0; $monitor_i < count($displayMonitors); $monitor_i += 1) {
     #FIXME replace this with a check for runstate vs dbstate
   }
 
-  $scale = max(reScale(SCALE_BASE, $monitor['DefaultScale'], ZM_WEB_DEFAULT_SCALE), SCALE_BASE);
   $stream_available = canView('Stream') and $monitor['Type']=='WebSite' or ($monitor['CaptureFPS'] && $monitor['Capturing'] != 'None');
 
   if ($canEditMonitors) {
@@ -408,16 +400,10 @@ for ($monitor_i = 0; $monitor_i < count($displayMonitors); $monitor_i += 1) {
   if ((!$monitor['UpdatedOn']) or (strtotime($monitor['UpdatedOn']) < time()-$fps_report_seconds)) {
     echo translate('Offline').'<br/>';
   } else {
-    echo 'Status: '.translate('Status'.$monitor['Status']).'<br/>';
-      echo translate('Capturing') . ': '.translate($monitor['Capturing']).'<br/>';
+    echo translate('Status'.$monitor['Status']).'<br/>';
     if ($monitor['Analysing'] != 'None') {
       echo translate('Analysing') . ': '.translate($monitor['Analysing']).'<br/>';
     }
-    if ($monitor['ObjectDetection'] != 'none') {
-      echo translate('Object Detection') . ': '.translate($monitor['ObjectDetection']);
-      if ($monitor['AnalysisFPSLimit']) echo ' '.$monitor['AnalysisFPSLimit'].'fps';
-      echo '<br/>';
-    }
     if ($monitor['Recording'] != 'None') {
       echo translate('Recording') . ': '.translate($monitor['Recording']) . ($monitor['ONVIF_Event_Listener'] ? ' Use ONVIF' : "") . '<br/>';
     }
@@ -429,8 +415,7 @@ for ($monitor_i = 0; $monitor_i < count($displayMonitors); $monitor_i += 1) {
       $fps_string .= $monitor['CaptureFPS'];
     }
 
-    if ( isset($monitor['AnalysisFPS'])) {
-     // and ($monitor['Analysing'] != 'None')) {
+    if ( isset($monitor['AnalysisFPS']) and ($monitor['Analysing'] != 'None')) {
       $fps_string .= '/' . $monitor['AnalysisFPS'];
     $total_analysis_fps += $monitor['AnalysisFPS'];
     }
