@@ -18,7 +18,7 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-if (!canView('Stream')) {
+if (!canView('Stream') or !$user->canViewView('montage')) {
   $view = 'error';
   return;
 }
@@ -117,7 +117,7 @@ if (isset($_REQUEST['zmMontageLayout'])) {
   $layout_id = validCardinal($_SESSION['zmMontageLayout']);
 }
 if (!$layout_id || !isset($layoutsById[$layout_id])) {
-  $layout_id = isset( $layoutsByName['Auto']) ? $layoutsByName['Auto']->Id() : 0;
+  $layout_id = $layoutsByName['Auto']->Id();
 }
 $layout = $layoutsById[$layout_id];
 $layout_is_preset = array_search($layout->Name(), $presetLayoutsNames) === false ? false : true;
@@ -202,7 +202,6 @@ foreach ($displayMonitors as &$row) {
     continue;
 
   $row['Scale'] = $scale;
-  $row['PopupScale'] = reScale(SCALE_BASE, $row['DefaultScale'], ZM_WEB_DEFAULT_SCALE);
 
   if (ZM_OPT_CONTROL && $row['ControlId'] && $row['Controllable'])
     $showControl = true;
@@ -371,15 +370,19 @@ foreach ($monitors as $monitor) {
         if (preg_match('/^(\d+) Wide$/', $layout->Name(), $matches)) {
           if ($matches[1]) {
             $monitor_options['scale'] = intval(100*(($browser_width/$matches[1])/$monitor->Width()));
-            if ($monitor_options['scale'] > 100) $monitor_options['scale'] = 100;
+            if ($monitor_options['scale'] < 10) $monitor_options['scale'] = 10;
+            else if ($monitor_options['scale'] > 100) $monitor_options['scale'] = 100;
           }
         }
       }
     } else {
+      $divisor = count($monitors)/2;
+      if ($divisor < 2) $divisor = 2;
+
       # Custom, default to 25% of 1920 for now, because 25% of a 4k is very different from 25% of 640px
-      $monitor_options['scale'] = intval(100*(($browser_width/4)/$monitor->Width()));
+      $monitor_options['scale'] = intval(100*(($browser_width/$divisor)/$monitor->Width()));
       if ($monitor_options['scale'] > 100) $monitor_options['scale'] = 100;
-      if ($monitor_options['scale'] < 10) $monitor_options['scale'] = 10;
+      else if ($monitor_options['scale'] < 10) $monitor_options['scale'] = 10;
     }
     $monitor->initial_scale($monitor_options['scale']);
     echo $monitor->getStreamHTML($monitor_options);
