@@ -71,6 +71,7 @@ echo getNavBarHTML();
         </div><!--header-->
         <div id="content-inner">
           <div class="BasicInformation">
+            <fieldset><legend>Profile</legend>
             <table id="contentTable" class="table">
               <tbody>
   <?php
@@ -117,11 +118,11 @@ echo getNavBarHTML();
 <?php
     $homeview_options = [
       'console'=>translate('Console'),
-      'events'=>'Events',
-      'map'   =>  'Map',
-      'montage'=>'Montage',
-      'montagereview'=>'Montage Review',
-      'watch' => 'Watch',
+      'events'=> translate('Events'),
+      'map'   =>  translate('Map'),
+      'montage'=> translate('Montage'),
+      'montagereview'=> translate('Montage Review'),
+      'watch' => translate('Watch'),
     ];
 echo htmlSelect('user[HomeView]', $homeview_options, $User->HomeView());
 ?></td>
@@ -149,12 +150,40 @@ echo htmlSelect('user[HomeView]', $homeview_options, $User->HomeView());
   ?>
             </tbody>
           </table>
+          </fieldset>
         </div><!--end basic information-->
 <?php
 if (canEdit('System')) {
 ?>
+<div id="ViewPermissions">
+  <fieldset><legend><?php echo translate('View Permissions') ?></legend>
+    <table id="viewPermissionsTable" class="major">
+      <thead class="thead-highlight">
+        <th class="View"><?php echo translate('View') ?></th>
+        <th class="permission"><?php echo translate('Permission') ?></th>
+      </thead>
+      <tbody>
+<?php
+  global $available_views;
+  $views = array_keys($available_views);
+  sort($views);
+  foreach ($views as $view) {
+    echo '
+  <tr class="view">
+    <td class="View">'.validHtmlStr($available_views[$view]).'</td>
+    <td class="permission">'.html_radio('view_permissions['.$view.']', $yesno,
+      $User->View_Permission($view)->Permission(),
+    ).'</td>
+  </tr>';
+  }
+?>
+      </tbody>
+    </table>
+  </fieldset>
+</div>
         <div class="Permissions">
-          <table id="contentTable" class="table">
+<fieldset><legend>Basic Permissions</legend>
+          <table id="permissionsTable" class="table">
             <tbody>
               <tr class="Stream">
                 <th scope="row"><?php echo translate('Stream') ?></th>
@@ -192,6 +221,7 @@ if (canEdit('System')) {
               </tr>
             </tbody>
           </table>
+</fieldset>
         </div><!--Permissions-->
       <br class="clear"/>
 <?php
@@ -214,7 +244,7 @@ if (canEdit('Groups')) {
 ?>
     <div id="GroupPermissions">
       <fieldset><legend><?php echo translate('Groups Permissions') ?></legend>
-        <table id="contentTable" class="major Groups">
+        <table id="groupPermissionsTable" class="major Groups">
           <thead class="thead-highlight">
             <tr>
               <th class="name" colspan="<?php echo $max_depth+1 ?>"><?php echo translate('Name') ?></th>
@@ -261,7 +291,7 @@ if (canEdit('Groups')) {
 ?>
 <div id="MonitorPermissions">
   <fieldset><legend><?php echo translate('Monitor Permissions') ?></legend>
-    <table id="contentTable" class="major Monitors">
+    <table id="monitorPermissionsTable" class="major Monitors">
       <thead class="thead-highlight">
         <tr>
           <th class="Id"><?php echo translate('Id') ?></th>
@@ -294,6 +324,7 @@ if (canEdit('Groups')) {
     </table>
   </fieldset>
 </div>
+
 <?php
 } // end if canEdit(System)
 ?>
